testlogger

package
v1.27.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	TestTimeout   = 10 * time.Minute
	TestSlowRun   = 10 * time.Second
	TestSlowFlush = 1 * time.Second
)
var WriterCloser = &testLoggerWriterCloser{}

Functions

func Init

func Init()

func MainErrorf

func MainErrorf(msg string, a ...any) int

MainErrorf is used to report an error from TestMain and return a non-zero value to indicate the failure

func PrintCurrentTest

func PrintCurrentTest(t testing.TB, skip ...int) func()

PrintCurrentTest prints the current test to os.Stdout

Types

type TestLogEventWriter

type TestLogEventWriter struct {
	*log.EventWriterBaseImpl
}

TestLogEventWriter is a logger which will write to the testing log

Jump to